@@ -30,14 +30,19 @@ class BoundK8SInfo(AbstractModel):
         :param BoundClusterType: 绑定的kubernetes的集群类型，分tke和eks两种
 注意：此字段可能返回 null，表示取不到有效值。
         :type BoundClusterType: str
+        :param SyncMode: 服务同步模式，all为全量同步，demand为按需同步
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SyncMode: str
         """
         self.BoundClusterId = None
         self.BoundClusterType = None
+        self.SyncMode = None
 
 
     def _deserialize(self, params):
         self.BoundClusterId = params.get("BoundClusterId")
         self.BoundClusterType = params.get("BoundClusterType")
+        self.SyncMode = params.get("SyncMode")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -98,6 +103,12 @@ class DescribeSREInstanceAccessAddressResponse(AbstractModel):
         :param ConsoleIntranetAddress: 控制台内网访问地址
 注意：此字段可能返回 null，表示取不到有效值。
         :type ConsoleIntranetAddress: str
+        :param InternetBandWidth: 客户端公网带宽
+注意：此字段可能返回 null，表示取不到有效值。
+        :type InternetBandWidth: int
+        :param ConsoleInternetBandWidth: 控制台公网带宽
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ConsoleInternetBandWidth: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -106,6 +117,8 @@ class DescribeSREInstanceAccessAddressResponse(AbstractModel):
         self.EnvAddressInfos = None
         self.ConsoleInternetAddress = None
         self.ConsoleIntranetAddress = None
+        self.InternetBandWidth = None
+        self.ConsoleInternetBandWidth = None
         self.RequestId = None
 
 
@@ -120,6 +133,8 @@ class DescribeSREInstanceAccessAddressResponse(AbstractModel):
                 self.EnvAddressInfos.append(obj)
         self.ConsoleInternetAddress = params.get("ConsoleInternetAddress")
         self.ConsoleIntranetAddress = params.get("ConsoleIntranetAddress")
+        self.InternetBandWidth = params.get("InternetBandWidth")
+        self.ConsoleInternetBandWidth = params.get("ConsoleInternetBandWidth")
         self.RequestId = params.get("RequestId")
 
 
@@ -253,6 +268,14 @@ class EnvInfo(AbstractModel):
         :type EnableConfigInternet: bool
         :param ConfigInternetServiceIp: config-server公网访问地址
         :type ConfigInternetServiceIp: str
+        :param SpecId: 规格ID
+        :type SpecId: str
+        :param EnvReplica: 环境的节点数
+        :type EnvReplica: int
+        :param RunningCount: 环境运行的节点数
+        :type RunningCount: int
+        :param AliasEnvName: 环境别名
+        :type AliasEnvName: str
         """
         self.EnvName = None
         self.VpcInfos = None
@@ -262,6 +285,10 @@ class EnvInfo(AbstractModel):
         self.ConfigServiceIp = None
         self.EnableConfigInternet = None
         self.ConfigInternetServiceIp = None
+        self.SpecId = None
+        self.EnvReplica = None
+        self.RunningCount = None
+        self.AliasEnvName = None
 
 
     def _deserialize(self, params):
@@ -278,6 +305,10 @@ class EnvInfo(AbstractModel):
         self.ConfigServiceIp = params.get("ConfigServiceIp")
         self.EnableConfigInternet = params.get("EnableConfigInternet")
         self.ConfigInternetServiceIp = params.get("ConfigInternetServiceIp")
+        self.SpecId = params.get("SpecId")
+        self.EnvReplica = params.get("EnvReplica")
+        self.RunningCount = params.get("RunningCount")
+        self.AliasEnvName = params.get("AliasEnvName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -411,6 +442,24 @@ class SREInstance(AbstractModel):
         :param EnableConsoleIntranet: 引擎实例是否开启控制台内网访问地址
 注意：此字段可能返回 null，表示取不到有效值。
         :type EnableConsoleIntranet: bool
+        :param ConfigInfoVisible: 引擎实例是否展示参数配置页面
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ConfigInfoVisible: bool
+        :param ConsoleDefaultPwd: 引擎实例控制台默认密码
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ConsoleDefaultPwd: str
+        :param TradeType: 交易付费类型，0后付费/1预付费
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TradeType: int
+        :param AutoRenewFlag: 自动续费标记：0表示默认状态(用户未设置，即初始状态)， 1表示自动续费，2表示明确不自动续费
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AutoRenewFlag: int
+        :param CurDeadline: 预付费到期时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CurDeadline: str
+        :param IsolateTime: 隔离开始时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IsolateTime: str
         """
         self.InstanceId = None
         self.Name = None
@@ -435,6 +484,12 @@ class SREInstance(AbstractModel):
         self.Tags = None
         self.EnableConsoleInternet = None
         self.EnableConsoleIntranet = None
+        self.ConfigInfoVisible = None
+        self.ConsoleDefaultPwd = None
+        self.TradeType = None
+        self.AutoRenewFlag = None
+        self.CurDeadline = None
+        self.IsolateTime = None
 
 
     def _deserialize(self, params):
@@ -481,6 +536,12 @@ class SREInstance(AbstractModel):
                 self.Tags.append(obj)
         self.EnableConsoleInternet = params.get("EnableConsoleInternet")
         self.EnableConsoleIntranet = params.get("EnableConsoleIntranet")
+        self.ConfigInfoVisible = params.get("ConfigInfoVisible")
+        self.ConsoleDefaultPwd = params.get("ConsoleDefaultPwd")
+        self.TradeType = params.get("TradeType")
+        self.AutoRenewFlag = params.get("AutoRenewFlag")
+        self.CurDeadline = params.get("CurDeadline")
+        self.IsolateTime = params.get("IsolateTime")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -507,12 +568,15 @@ class ServiceGovernanceInfo(AbstractModel):
         :type AuthOpen: bool
         :param Features: 该实例支持的功能，鉴权就是 Auth
         :type Features: list of str
+        :param MainPassword: 主账户名默认为 polaris，该值为主账户的默认密码
+        :type MainPassword: str
         """
         self.EngineRegion = None
         self.BoundK8SInfos = None
         self.VpcInfos = None
         self.AuthOpen = None
         self.Features = None
+        self.MainPassword = None
 
 
     def _deserialize(self, params):
@@ -531,6 +595,7 @@ class ServiceGovernanceInfo(AbstractModel):
                 self.VpcInfos.append(obj)
         self.AuthOpen = params.get("AuthOpen")
         self.Features = params.get("Features")
+        self.MainPassword = params.get("MainPassword")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
